pub fn style_document(
tokenized: TokenizedDocument,
theme: &Theme,
) -> HighlightedDocumentExpand description
Resolves a tokenized document against a theme without retokenizing source.
pub fn style_document(
tokenized: TokenizedDocument,
theme: &Theme,
) -> HighlightedDocumentResolves a tokenized document against a theme without retokenizing source.